---
layout: page
title: Module Information
description: General information about MUDE.
nav_order: 2
nav_exclude: false
---

<!-- <a href="" target="_blank"></a> -->
<!-- [](.md) -->

# Module Information

An overview of the module and some key policies are described on this page, adding to the description provided in the <a href="https://studiegids.tudelft.nl/a101_displayCourse.do?course_id=69347" target="_blank">Study Guide</a>.

_Updates to the material on this page will be accompanied by announcements in class during the Monday lectures and and via the [Announcements](../announcements/) page on this website._

MUDE is built on a repetitive and consistent weekly schedule, which is illustrated on the [Schedule page](../schedule), along with a list of topics, by week.

If the information below does not answer your question, first check the [Answers Platform](https://answers.citg.tudelft.nl/){:target="_blank"} (described [below](#answers-platform)). If that doesn't help, you can contact MUDE staff at MUDE-CEG@tudelft.nl.

This page contains the following sections:
- [Module Information](#module-information)
  - [Assessment](#assessment)
  - [Assignments](#assignments)
  - [Weekly Schedule](#weekly-schedule)
    - [In-Class Sessions](#in-class-sessions)
    - [Question Hours](#question-hours)
  - [Online Resources](#online-resources)
    - [Answers Platform](#answers-platform)
  - [Attendance](#attendance)
  - [Conduct](#conduct)

## Assessment

Your total MUDE grade consists of three assessments:	
- Exam at end of Q1 (resit in Q2) (25%)
- Exam at end of Q2 (resit in Q3) (25%)
- Assignment Portfolio (50%)

You will pass the module if you obtained at least a 5.8 for the three individual components. There will be a resit opportunity for the exams. If the grade for your Assignment Portfolio is below 5.8, you will get the opportunity to submit a revised version for which you will get a 6.0 if judged sufficient.

This website has separate pages to describe the [Exams](../exams) and the [Assignment Portfolio](../portfolio).

Note that the first part of Q1 is used to get used to the weekly MUDE activities and workflow; therefore, **none of the work during the first two weeks of Q1 is part of the Assignment Portfolio grade** (but the content is still part of the exam!).

## Assignments

There are three types of assignments every week, each of which is described below:
- **Programming Assignments (PA)**: individual, part of Assignment Portfolio grade.
- **Workshops (WS)**: assigned and completed during Wednesday sessions. _Not_ part of Assignment Portfolio grade.
- **Group Assignments (GA)**: completed in groups during Friday sessions. Part of Assignment Portfolio grade.

Assignments (and weeks) are numbered to indicate the quarter and week in which they occur. For example, PA 1.4 is the Programming Assignment for week 4 in quarter 1. Files and folders will use an underscore, for example `PA_1_4_*.ipynb` will be stored in folder `Week_1_4`.

GitLab will be used to submit PA's and GA's and to recieve feedback from instructors. Instructions for how to access and use GitLab will be provided over the first two weeks of Q1.

## Weekly Schedule

Each week begins with a lecture on Monday (except Week 1.1, which is on Tuesday!) and ends with a Group Assignment completed in-class on a Friday; question hours, Programming Assignments and Wednesday Workshops are designed to help you learn the topic for each week in a structured way that is repeated each week. See the [weekly schedule page](../shedule) for an illustration.

### In-Class Sessions

The in-class sessions on Wednesday and Friday are designed for you to work collaboratively with classmates and be able to easily ask questions to teachers. We will be distributed over multiple locations, with instructors in each room. Room assignments will be posted to this website each week, by group number. You are not required to work with your group during the Wednesday sessions, although it is a useful moment to reflect on the Group Assignment from the previous week and plan for the upcoming Friday. Attendance is required for the Friday sessions (see [Attendance section below](#attendance)).

### Question Hours

The best chance for you to ask in-person questions about MUDE is during the Tuesday question hour, when we will have multiple teachers present to help with the theoretical topics, as well as issues related to programming.

Thursday is planned during the lunch period due to the fact that all three MSc programs have full schedules on that day; it is provided in case you need a question answered before the Friday session (for example, perhaps you are trying to finish the programming assignment). There will be only 1 or 2 teachers present on Thursday.

Monday question hours are held in 3.80.6 with Robert Lanzafame and are meant for quick questions or personal issues. As the room is small, please line up outside the door if there is a student ahead of you. Note that these sessions are _not_ visible in MyTimeTable. 

Tuesday Question Hours are additionally scheduled during Weeks 1.9, 2.9, 2.10 and 3.9 for exam review.

## Online Resources

There are several online resources for this module, most of which are available with a quick-link in the top right corner of this website:
- **MUDE Online Textbook**: weekly reading, along with interactive exercises to practice and study the material. 
- **Answers Platform** ([answers.citg.tudelft.nl](https://answers.citg.tudelft.nl/)) a stack-exchange-style platform; you are encouraged to post questions _and_ answers!
- **Files Page** ([mude.citg.tudelft.nl/2024/files/](https://mude.citg.tudelft.nl/2024/files/)): key files for easy access. Notebook files (`*.ipynb`) will be converted to HTML for easy online viewing; however the complete set of files required for an assignment (e.g., `*.py` or data files) will only be available via GitLab.
- **GitLab**: starting in week 3 this will be our primary platform for sharing and submitting assignments, as well as receiving feedback. In Weeks 1 and 2 you will download your assignments from GitLab, but not submit them.
- **Collegerama**: Our Monday lectures are available to stream online [here](https://collegeramavideoportal.tudelft.nl/catalogue/cegm1000/?academicYear=2024-2025-cegm1000).
- **Brightspace:** annoucements and BuddyCheck. To make sure you never miss an announcement, get the Pulse app! An overview with instructions can be found [here](https://teaching-support.tudelft.nl/how-to-use-pulse/).
- **BuddyCheck:** A peer feedback tool that will be completed on a weekly bases to monitor your group and improve your ability to work together. Described in detail on the [Assignment Portfolio page](./portfolio).

Please note that content in the online textbook will be added on a weekly basis throughout the module, and changes will be announced and documented as needed. When new content is added, it will be done in large chunks. Changes will not be made retroactively that impact the scope of the exams (in other words, you will never need to re-study material because it changed prior to the exam). Notifications of errors, corrections and suggestions for improvement are glady welcomed via the Answers platform and/or via the MUDE email address.

### Answers Platform

The [Answers Platform](https://answers.citg.tudelft.nl/){:target="_blank"} is a website where you can find Answers to questions asked by yourself, other students and course staff. Ask anything you want related to MUDE!

The platform works by providing (and discussing) answers to questions, then voting whether or not you find the answer to be useful. You can also track statistics as you participate in the platform, giving it a bit of a competitive side: we will be periodically awarding prizes to students who make exceptional contributions to the Answers platform throughout the semester! In addition, this is also a useful metric we have for selecting future MUDE TA's.

There are numerous benefits for sharing our questions and answers on this platform. To ensure it becomes a useful resource, please consider the following guidelines:
1. Questions and answers should be written as if they were a standalone document. You should not use it as if it were a WhatsApp or email conversation.
2. Add a vote if something is useful or not. If you like a question or answer, give it an upvote! Downvotes are also informative (try to use the comment thread to indicate why).
3. Edit your posts instead of adding a second post with a correction. Use the comment thread to discuss or explain confusion.
4. Ask questions and post answers that are clear enough to be answered without searching for additional material. For example, write the equation in question or include a screenshot; include a snippet of code if it is programming related.
5. Do not include personal information in your post.
6. Do not ask questions to course staff individually or to the MUDE email address; instead, use the MUDE email to request an answer to a question that has remained unanswered for a few days; include the link so it is easy for course staff to find.

<!-- Use the [Meta tab](https://answers.citg.tudelft.nl/categories/15){:target="_blank"} if you have questions for how the platform works (this is especially well-developed on the [page for the math department](https://answers.ewi.tudelft.nl/categories/2){:target="_blank"}). -->

## Attendance

Attendance in class is highly encouraged for the Monday and Wednesday sessions to stay on top of the material. However, attendance is mandatory only for the Group Assignment sessions on Friday. Most importantly, you should inform your group members in advance if you will not be present! You are free to arrange with each other to share the workload and catch up if a group member misses a Friday session (see also the [Conduct Section below](#conduct)).

You are allowed to miss one session without obtaining prior permission. If you expect to miss more than one Friday session during a quarter, you should inform MUDE staff immediately, as repeated absences can impact your Group Assignments and cause a reduced Assignment Portfolio grade. 

## Conduct

As MUDE Staff, we do our best to accomodate all students and answer your questions as quickly as possible. However, this is a challenge with a large module of around 300 students. To help us in this regard, we kindly ask for your patience and understanding; we also appreciate you checking the [Answers Platform](https://answers.citg.tudelft.nl/){:target="_blank"} and coming to our in-class sessions and question hours rather than asking questions about the course content via email. That said, do not hesitate to email us at MUDE-CEG@tudelft.nl if you have a challenging personal situation.

We expect all students and staff to adhere to the TU Delft [Code of Conduct](https://www.tudelft.nl/en/about-tu-delft/strategy/integrity-policy/tu-delft-code-of-conduct). In addition, there are several important points to consider for MUDE specifically.

In terms of your assignments, we expect an honest effort and integrity: if you submit work that is not your own you should explicitly explain this in your submission. Failure to do so will result in grade reduction. We will run plagiarism checks throughout the semester on your work, and incidents will be reported directly to the Board of Examiners (you can learn more about the policy <a href="https://www.tudelft.nl/en/student/ceg-student-portal/education/education-information/academic-attitude" target="_blank">here</a>). In order to avoid this, please follow the following guidelines when working on and submitting your MUDE assignments:
- You are free to use an AI tool, but we strongly recommend you try to ask small questions, rather than pasting the entire question prompt from an assignment. Never copy and paste the entire answer from an AI tool into your assignment submission. Our advice is to use AI tools to generate ideas, not answer questions.
- Always: a) write code yourself as much as possible, and 2) understand what it is you are writing: this is a much better strategy for learning, and, while it may be slow at first, you will find that in the long run you will need to copy/paste less often!
- Reading and looking at the work of classmates is OK, but avoid copy and paste of a) entire files, and b) large pieces of text or code. If you re-use more than a small number of sentences or lines you should clearly state that you have done so in your assignments. For example, write down the names of students with whom you worked or add a note that you developed a piece of the code from a ChatGPT answer. Note that answers in your Group Assignments which appears to come from another source, such as an AI tool, without citation, will result in points being deducted.

With regards to **group work**, the items above apply; in addition, you are expected to:
- Share the workload in an equitable way.
- Consider each members strengths and weaknesses and support each other to improve over the quarter.
- Inform your group members if your contribution to an assignment is not your own work (for example, from an AI tool or another classmate)
- Communicate in advance if you will be absence and coordinate with each other to make sure the Group Assignments are completed equitably. You are free to do this for a single week, or over the entire quarter, as long as all members consent.
- Use BuddyCheck to honestly evaluate the contributions of yourself and your group members individually.
- If there are problems with your group, use the weekly BuddyChecks to inform course staff. If you think the BuddyCheck is not sufficient, do not hesitate to contact course staff directly at MUDE-CEG@tudelft.nl (all communication will remain confidential).
- Don't wait until the end of the quarter to report issues with your group: the earler the better!

<!-- - Re-use material with a suitable license (for example, <a href="https://creativecommons.org/licenses/by/2.0/" target="_blank">Creative Commons CC-BY</a> allows re-use with proper acknowledgement). -->
